..
    This file is part of Invenio.
    Copyright (C) 2016-2018 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

API Docs
========

.. automodule:: invenio_oaiserver.ext
   :members:

Models
------

.. automodule:: invenio_oaiserver.models
   :members:

Views
-----

.. automodule:: invenio_oaiserver.views
   :members:

.. automodule:: invenio_oaiserver.verbs
   :members:

.. automodule:: invenio_oaiserver.admin
   :members:

Response
--------

.. automodule:: invenio_oaiserver.response
   :members:

.. automodule:: invenio_oaiserver.query
   :members:

.. automodule:: invenio_oaiserver.resumption_token
   :members:

Persistent identifier
---------------------

.. automodule:: invenio_oaiserver.provider
   :members:

.. automodule:: invenio_oaiserver.minters
   :members:

.. automodule:: invenio_oaiserver.fetchers
   :members:

Utilities
---------

.. automodule:: invenio_oaiserver.utils
   :members:

.. automodule:: invenio_oaiserver.errors
   :members:
